@@ -211,14 +211,21 @@ liqcell *liqrecentsketches_create()
 
 	if(self)
 	{
-		//liqcell_propsets(  self, "backcolor", "rgb(255,255,255)" );
+	//	liqcell_propsets(  self, "backcolor", "rgb(255,255,255)" );
 
 
-		liqcell *body = liqcell_quickcreatevis("body","frame",0 ,0,   self->w,self->h);
 
 
 		char buf[FILENAME_MAX];    snprintf(buf,sizeof(buf),"%s/.sketches",app.userdatapath);
 
+
+if(liqapp_pathexists(buf))
+{
+	
+	liqapp_log("recent sketches buf=%s",buf);
+	
+		liqcell *body = liqcell_quickcreatevis("body","frame",0 ,0,   self->w,self->h);
+
 		liqcell_scan_folder_for_images(body,buf);
 		
 		liqcell_child_insert( self, body );
@@ -238,6 +245,7 @@ liqcell *liqrecentsketches_create()
 		//liqcell_handleradd(self,    "click",   float_click);
 
 
+#ifdef USE_INOTIFY
 		//############################# timer1:liqtimer
 		liqcell *timer1=liqcell_quickcreatevis("timer1",   "liqtimer",   0,0,   0,0 );
 		// store ourselves on the tag for use later
@@ -247,6 +255,10 @@ liqcell *liqrecentsketches_create()
 		liqcell_handleradd_withcontext(timer1,"timertick",timer_tick,self);
 		liqcell_setenabled(timer1,1);
 		liqcell_child_insert( self,timer1);
+#endif
+
+
+}
 
 	}
 	
@@ -386,6 +398,12 @@ static int monitor_run(liqcell *context)
 
 	char * folder = liqcell_propgets(context,"monitorpath",".");
 
+	if( (!folder) || (!*folder) || (!liqapp_pathexists(folder)) )
+	{
+      liqapp_log( "monitor path does not exist\n");
+      return -1;		
+	}
+
    strcpy (target, folder);
 
    fd = inotify_init();
@@ -395,7 +413,7 @@ static int monitor_run(liqcell *context)
       return 1;
    }
    
-   wd = inotify_add_watch(fd, target, IN_ALL_EVENTS);
+   wd = inotify_add_watch(fd, target, IN_CLOSE_WRITE);//IN_ALL_EVENTS);
    if (wd < 0)
    {
       liqapp_log( "monitor error add: %s\n", strerror(errno));
@@ -404,6 +422,7 @@ static int monitor_run(liqcell *context)
    
    while (1)
    {
+		liqapp_sleep(25);
       monitor_get_event(fd, target,context);
    }
 
